Package: netUtils
Title: A Collection of Tools for Network Analysis
Version: 0.8.6
Authors@R: 
    person("David", "Schoch", email = "david@schochastics.net", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-2952-4812"))
Description: Provides a collection of network analytic (convenience) functions which are missing in other standard packages. This includes triad census with attributes <doi:10.1016/j.socnet.2019.04.003>, core-periphery models <doi:10.1016/S0378-8733(99)00019-2>, and several graph generators. Most functions are build upon 'igraph'.  
URL: https://github.com/schochastics/netUtils/,
        https://schochastics.github.io/netUtils/
BugReports: https://github.com/schochastics/netUtils/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
LinkingTo: Rcpp, RcppArmadillo
Imports: Rcpp, igraph (>= 2.0.0), stats
Suggests: covr, GA, testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2026-06-12 19:23:15 UTC; david
Author: David Schoch [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2952-4812>)
Maintainer: David Schoch <david@schochastics.net>
Repository: CRAN
Date/Publication: 2026-06-12 20:40:02 UTC
