# Generated by roxygen2: do not edit by hand

S3method(graph_cor,array)
S3method(graph_cor,default)
S3method(graph_cor,igraph)
S3method(graph_cor,matrix)
S3method(str,igraph)
export(as_adj_list1)
export(as_adj_weighted)
export(as_multi_adj)
export(biggest_component)
export(bipartite_from_data_frame)
export(clique_vertex_mat)
export(core_periphery)
export(delete_isolates)
export(dyad_census_attr)
export(graph_cartesian)
export(graph_cor)
export(graph_direct)
export(graph_from_multi_edgelist)
export(graph_kpartite)
export(reciprocity_cor)
export(sample_coreseq)
export(sample_lfr)
export(sample_pa_homophilic)
export(split_graph)
export(structural_equivalence)
export(triad_census_attr)
importFrom(Rcpp,sourceCpp)
useDynLib(netUtils, .registration = TRUE)
