# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

benchmark <- function(excess, defect, num_nodes, average_k, max_degree, tau, tau2, mixing_parameter, overlapping_nodes, overlap_membership, nmin, nmax, fixed_range) {
    .Call(`_netUtils_benchmark`, excess, defect, num_nodes, average_k, max_degree, tau, tau2, mixing_parameter, overlapping_nodes, overlap_membership, nmin, nmax, fixed_range)
}

mse <- function(adjList, deg) {
    .Call(`_netUtils_mse`, adjList, deg)
}

sortxy <- function(x, y) {
    .Call(`_netUtils_sortxy`, x, y)
}

triadCensusCol <- function(A, attr, orbitClasses, triads) {
    .Call(`_netUtils_triadCensusCol`, A, attr, orbitClasses, triads)
}

